"""
This example illustrates how a set of structure predictions can be compared to a target 
structure.

We use 3 predicted structures for the target sequence of PDB ID 4GB5.A
"""

from ost.bindings import dssp
servers = ['server11', 'server7', 'server8']

target = io.LoadPDB('data/target.pdb')
dssp.AssignDSSP(target)

gfx_target = gfx.Entity('target', gfx.TUBE, target)
gfx_target.outline = True
gfx_target.outline_mode = 3

scene.Add(gfx_target)
scene.bg = gfx.WHITE
# create list of local distances for the target structure. This list is required for 
# the lDDT calculation...
target_dist_list = mol.alg.CreateDistanceList(target.Select(''), 15)
traffic_light_gradient = gfx.Gradient([gfx.RED, gfx.YELLOW, gfx.GREEN])

for server in servers:
  server_model = io.LoadPDB('data/%s.pdb' % server)
  dssp.AssignDSSP(server_model)
  trimmed_server_model = server_model.Select('rnum=5:152')
  gfx_server_model = gfx.Entity(server, gfx.TUBE, trimmed_server_model)
  gfx_server_model.outline = True
  gfx_server_model.outline_mode = 3
  scene.Add(gfx_server_model)
  mol.alg.LDDTHA(trimmed_server_model, target_dist_list)
  gfx_server_model.ColorBy('locallddt', traffic_light_gradient, 
                           0, 1, mol.Prop.Level.RESIDUE)
  

